SmartLedsAdapterAsync

Struct SmartLedsAdapterAsync 

pub struct SmartLedsAdapterAsync<'ch, const BUFFER_SIZE: usize, Color = Grb<u8>> { /* private fields */ }
Adapter taking an RMT channel and a specific pin and providing RGB LED interaction functionality.

Implementations

Source

impl<'ch, const BUFFER_SIZE: usize> SmartLedsAdapterAsync<'ch, BUFFER_SIZE, Grb<u8>>

pub fn new<C, O>( channel: C, pin: O, rmt_buffer: &'ch mut [PulseCode; BUFFER_SIZE], ) -> Self
where O: PeripheralOutput<'ch>, C: TxChannelCreator<'ch, Async>,

Create a new adapter object that drives the pin using the RMT channel.

Source

impl<'ch, const BUFFER_SIZE: usize, Color> SmartLedsAdapterAsync<'ch, BUFFER_SIZE, Color>
where Color: ComponentSlice<u8>,

pub fn new_with_color<C, O>( channel: C, pin: O, rmt_buffer: &'ch mut [PulseCode; BUFFER_SIZE], ) -> SmartLedsAdapterAsync<'ch, BUFFER_SIZE, Color>
where O: PeripheralOutput<'ch>, C: TxChannelCreator<'ch, Async>,

Create a new adapter object that drives the pin using the RMT channel.