pub struct Timing {
pub time_0_low: u16,
pub time_0_high: u16,
pub time_1_low: u16,
pub time_1_high: u16,
pub reset: u16,
}Expand description
Defines the timing for a certain smart LED type.
All common smart LEDs are controlled by sending PWM-like pulses, in two different configurations for high and low. The required timings (and tolerances) can be found in the relevant datasheets.
Provided timings: SK68XX_TIMING, WS2812B_TIMING, WS2811_TIMING, WS2812_TIMING.
Fields
time_0_low: u16Low time for zero pulse, in nanoseconds.
time_0_high: u16High time for zero pulse, in nanoseconds.
time_1_low: u16Low time for one pulse, in nanoseconds.
time_1_high: u16High time for one pulse, in nanoseconds.
reset: u16Time for the reset that is required in between transmissions, in nanoseconds.