pub struct SmartLedsAdapterAsync<'ch, const BUFFER_SIZE: usize, Color = Grb<u8>> { /* private fields */ }Expand description
Adapter taking an RMT channel and a specific pin and providing RGB LED interaction functionality.
Implementations
Sourceimpl<'ch, const BUFFER_SIZE: usize> SmartLedsAdapterAsync<'ch, BUFFER_SIZE, Grb<u8>>
impl<'ch, const BUFFER_SIZE: usize> SmartLedsAdapterAsync<'ch, BUFFER_SIZE, Grb<u8>>
Sourcepub fn new<C, O>(
channel: C,
pin: O,
rmt_buffer: &'ch mut [PulseCode; BUFFER_SIZE],
) -> Self
pub fn new<C, O>( channel: C, pin: O, rmt_buffer: &'ch mut [PulseCode; BUFFER_SIZE], ) -> Self
Create a new adapter object that drives the pin using the RMT channel.
Sourceimpl<'ch, const BUFFER_SIZE: usize, Color> SmartLedsAdapterAsync<'ch, BUFFER_SIZE, Color>where
Color: ComponentSlice<u8>,
impl<'ch, const BUFFER_SIZE: usize, Color> SmartLedsAdapterAsync<'ch, BUFFER_SIZE, Color>where
Color: ComponentSlice<u8>,
Sourcepub fn new_with_color<C, O>(
channel: C,
pin: O,
rmt_buffer: &'ch mut [PulseCode; BUFFER_SIZE],
) -> SmartLedsAdapterAsync<'ch, BUFFER_SIZE, Color>
pub fn new_with_color<C, O>( channel: C, pin: O, rmt_buffer: &'ch mut [PulseCode; BUFFER_SIZE], ) -> SmartLedsAdapterAsync<'ch, BUFFER_SIZE, Color>
Create a new adapter object that drives the pin using the RMT channel.